==> cleaver_1.14.0.zip: cleaver/doc/cleaver.R <==
## ----style, eval=TRUE, echo=FALSE, results="asis"---------------------------------------
BiocStyle::latex(use.unsrturl=FALSE)

## ----setup, include=FALSE, cache=FALSE--------------------------------------------------
library("knitr")
opts_chunk$set(tidy.opts=list(width.cutoff=45, tidy=FALSE), fig.align='center', comment=NA, prompt=TRUE)

## ----libraries, echo=FALSE--------------------------------------------------------------
suppressPackageStartupMessages(library("UniProt.ws"))
suppressPackageStartupMessages(library("BRAIN"))

## ---------------------------------------------------------------------------------------
library("cleaver")

## ----eval=FALSE-------------------------------------------------------------------------
#  help("cleave")

## ---------------------------------------------------------------------------------------
## cleave it
cleave("LAAGKVEDSD", enzym="trypsin")
## get the cleavage ranges
cleavageRanges("LAAGKVEDSD", enzym="trypsin")
## get only cleavage sites
cleavageSites("LAAGKVEDSD", enzym="trypsin")

## ---------------------------------------------------------------------------------------
## miss one cleavage position
cleave("LAAGKVEDSD", enzym="trypsin", missedCleavages=1)
cleavageRanges("LAAGKVEDSD", enzym="trypsin", missedCleavages=1)
## miss zero or one cleavage positions
cleave("LAAGKVEDSD", enzym="trypsin", missedCleavages=0:1)
cleavageRanges("LAAGKVEDSD", enzym="trypsin", missedCleavages=0:1)

## ---------------------------------------------------------------------------------------
## create AAStringSet object
p <- AAStringSet(c(gaju="LAAGKVEDSD", pnm="AGEPKLDAGV"))

## cleave it
cleave(p, enzym="trypsin")
cleavageRanges(p, enzym="trypsin")
cleavageSites(p, enzym="trypsin")

## ---------------------------------------------------------------------------------------
## load UniProt.ws library
library("UniProt.ws")

## select species Homo sapiens
UniProt.ws <- UniProt.ws(taxId=9606)

## download sequences of Insulin/Somatostatin
s <- select(UniProt.ws, keys=c("P01308", "P61278"), columns=c("SEQUENCE"))

## fetch only sequences
sequences <- setNames(s$SEQUENCE, s$UNIPROTKB)

## remove whitespaces
sequences <- gsub(pattern="[[:space:]]", replacement="", x=sequences)

## ---------------------------------------------------------------------------------------
cleave(sequences, enzym="pepsin")

## ---------------------------------------------------------------------------------------
## load BRAIN library
library("BRAIN")

## cleave insulin
cleavedInsulin <- cleave(sequences[1], enzym="trypsin")[[1]]

## create empty plot area
plot(NA, xlim=c(150, 4300), ylim=c(0, 1),
     xlab="mass", ylab="relative intensity",
     main="tryptic digested insulin - isotopic distribution")

## loop through peptides
for (i in seq(along=cleavedInsulin)) {
  ## count C, H, N, O, S atoms in current peptide
  atoms <- BRAIN::getAtomsFromSeq(cleavedInsulin[[i]])
  ## calculate isotopic distribution
  d <- useBRAIN(atoms)
  ## draw peaks
  lines(d$masses, d$isoDistr, type="h", col=2)
}

## ----sessioninfo, echo=FALSE, results="asis"--------------------------------------------
toLatex(sessionInfo())

==> cleaver_1.20.0.zip: cleaver/doc/cleaver.R <==
## ----style, eval=TRUE, echo=FALSE, results="asis"--------------------------
BiocStyle::latex(use.unsrturl=FALSE)

## ----setup, include=FALSE, cache=FALSE-------------------------------------
library("knitr")
opts_chunk$set(tidy.opts=list(width.cutoff=45, tidy=FALSE), fig.align='center', comment=NA, prompt=TRUE)

## ----libraries, echo=FALSE-------------------------------------------------
suppressPackageStartupMessages(library("UniProt.ws"))
suppressPackageStartupMessages(library("BRAIN"))

## --------------------------------------------------------------------------
library("cleaver")

## ----eval=FALSE------------------------------------------------------------
#  help("cleave")

## --------------------------------------------------------------------------
## cleave it
cleave("LAAGKVEDSD", enzym="trypsin")
## get the cleavage ranges
cleavageRanges("LAAGKVEDSD", enzym="trypsin")
## get only cleavage sites
cleavageSites("LAAGKVEDSD", enzym="trypsin")

## --------------------------------------------------------------------------
## miss one cleavage position
cleave("LAAGKVEDSD", enzym="trypsin", missedCleavages=1)
cleavageRanges("LAAGKVEDSD", enzym="trypsin", missedCleavages=1)
## miss zero or one cleavage positions
cleave("LAAGKVEDSD", enzym="trypsin", missedCleavages=0:1)
cleavageRanges("LAAGKVEDSD", enzym="trypsin", missedCleavages=0:1)

## --------------------------------------------------------------------------
## create AAStringSet object
p <- AAStringSet(c(gaju="LAAGKVEDSD", pnm="AGEPKLDAGV"))

## cleave it
cleave(p, enzym="trypsin")
cleavageRanges(p, enzym="trypsin")
cleavageSites(p, enzym="trypsin")

## --------------------------------------------------------------------------
## load UniProt.ws library
library("UniProt.ws")

## select species Homo sapiens
UniProt.ws <- UniProt.ws(taxId=9606)

## download sequences of Insulin/Somatostatin
s <- select(UniProt.ws, keys=c("P01308", "P61278"), columns=c("SEQUENCE"))

## fetch only sequences
sequences <- setNames(s$SEQUENCE, s$UNIPROTKB)

## remove whitespaces
sequences <- gsub(pattern="[[:space:]]", replacement="", x=sequences)

## --------------------------------------------------------------------------
cleave(sequences, enzym="pepsin")

## --------------------------------------------------------------------------
## load BRAIN library
library("BRAIN")

## cleave insulin
cleavedInsulin <- cleave(sequences[1], enzym="trypsin")[[1]]

## create empty plot area
plot(NA, xlim=c(150, 4300), ylim=c(0, 1),
     xlab="mass", ylab="relative intensity",
     main="tryptic digested insulin - isotopic distribution")

## loop through peptides
for (i in seq(along=cleavedInsulin)) {
  ## count C, H, N, O, S atoms in current peptide
  atoms <- BRAIN::getAtomsFromSeq(cleavedInsulin[[i]])
  ## calculate isotopic distribution
  d <- useBRAIN(atoms)
  ## draw peaks
  lines(d$masses, d$isoDistr, type="h", col=2)
}

## ----sessioninfo, echo=FALSE, results="asis"-------------------------------
toLatex(sessionInfo())
